==========================================================
Example input files for testing pubmed-author-affiliations
==========================================================

These files contain Pubmed and DOI references linked to EMDB (emdb-empiar.org) entries for years 2010 to 2016. The
files ending in "-4.txt" refer to entries at 4 Angstroms or better.